summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/private/kopetecommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/private/kopetecommand.h')
-rw-r--r--kopete/libkopete/private/kopetecommand.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kopete/libkopete/private/kopetecommand.h b/kopete/libkopete/private/kopetecommand.h
index 6a686f1e..d49de208 100644
--- a/kopete/libkopete/private/kopetecommand.h
+++ b/kopete/libkopete/private/kopetecommand.h
@@ -30,12 +30,13 @@ class ChatSession;
class Command : public KAction
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a Kopete::Command object
*
* @param parent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
* accept two parameters, a TQString of arguments, and a Kopete::ChatSession
@@ -49,10 +50,10 @@ class Command : public KAction
* @param cut The shortcut for the command
* @param pix The icon to use for the command
*/
- Command( TQObject *parent, const TQString &command, const char* handlerSlot,
- const TQString &help = TQString::null, CommandHandler::CommandType type = CommandHandler::Normal, const TQString &formatString = TQString::null,
+ Command( TQObject *tqparent, const TQString &command, const char* handlerSlot,
+ const TQString &help = TQString(), CommandHandler::CommandType type = CommandHandler::Normal, const TQString &formatString = TQString(),
uint minArgs = 0, int maxArgs = -1, const KShortcut &cut = 0,
- const TQString &pix = TQString::null );
+ const TQString &pix = TQString() );
/**
* Process this command
@@ -30,12 +30,13 @@ class ChatSession;
* Creates a Kopete::Command object
*
- * @param parent The plugin who owns this command
+ * @param tqparent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must